==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/KeyUsage.h <==
// public class gnu.java.security.x509.ext.KeyUsage

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 66d99c6d29c9ffed gnu_java_security_x509_ext_KeyUsage
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_KeyUsage_H_
#define _JC_gnu_java_security_x509_ext_KeyUsage_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_der_BitString$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs	_jc_gnu_java_security_x509_ext_KeyUsage$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs	_jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$refs	_jc_gnu_java_security_x509_ext_KeyUsage$refs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$nonrefs	_jc_gnu_java_security_x509_ext_KeyUsage$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$object	_jc_gnu_java_security_x509_ext_KeyUsage$object;

typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct	_jc_gnu_java_security_x509_ext_KeyUsage$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vmethods	_jc_gnu_java_security_x509_ext_KeyUsage$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vtable	_jc_gnu_java_security_x509_ext_KeyUsage$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vtype	_jc_gnu_java_security_x509_ext_KeyUsage$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24KeyUsage;
	jint	CRL__5fSIGN;
	jint	DATA__5fENCIPHERMENT;
	jint	DECIPHER__5fONLY;
	jint	DIGITAL__5fSIGNATURE;
	jint	ENCIPHER__5fONLY;
	jint	KEY__5fAGREEMENT;
	jint	KEY__5fCERT__5fSIGN;
	jint	KEY__5fENCIPHERMENT;
	jint	NON__5fREPUDIATION;
};
extern _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct _jc_gnu_java_security_x509_ext_KeyUsage$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_KeyUsage$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_gnu_java_security_der_BitString$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$getKeyUsage$e8df32a6488835fe(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_KeyUsage$method_info$getKeyUsage$e8df32a6488835fe;
extern _jc_method _jc_gnu_java_security_x509_ext_KeyUsage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_KeyUsage$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$vmethods {
	struct _jc_gnu_java_security_der_BitString$object	*(*getKeyUsage$e8df32a6488835fe)(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_KeyUsage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_KeyUsage$vmethods	gnu_java_security_x509_ext_KeyUsage;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_KeyUsage$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_KeyUsage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs {
	struct _jc_gnu_java_security_der_BitString$object	*keyUsage;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_KeyUsage$refs {
    _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs	gnu_java_security_x509_ext_KeyUsage;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_KeyUsage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs	gnu_java_security_x509_ext_KeyUsage;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$object {
	_jc_gnu_java_security_x509_ext_KeyUsage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_KeyUsage$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_KeyUsage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_KeyUsage$vtype _jc_gnu_java_security_x509_ext_KeyUsage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_KeyUsage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_KeyUsage$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_KeyUsage_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/KeyUsage.h <==
// public class gnu.java.security.x509.ext.KeyUsage

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 66d99c6d29c9ffed gnu_java_security_x509_ext_KeyUsage
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_KeyUsage_H_
#define _JC_gnu_java_security_x509_ext_KeyUsage_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_der_BitString$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs	_jc_gnu_java_security_x509_ext_KeyUsage$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs	_jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$refs	_jc_gnu_java_security_x509_ext_KeyUsage$refs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$nonrefs	_jc_gnu_java_security_x509_ext_KeyUsage$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$object	_jc_gnu_java_security_x509_ext_KeyUsage$object;

typedef struct _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct	_jc_gnu_java_security_x509_ext_KeyUsage$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vmethods	_jc_gnu_java_security_x509_ext_KeyUsage$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vtable	_jc_gnu_java_security_x509_ext_KeyUsage$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_KeyUsage$vtype	_jc_gnu_java_security_x509_ext_KeyUsage$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24KeyUsage;
	jint	CRL__5fSIGN;
	jint	DATA__5fENCIPHERMENT;
	jint	DECIPHER__5fONLY;
	jint	DIGITAL__5fSIGNATURE;
	jint	ENCIPHER__5fONLY;
	jint	KEY__5fAGREEMENT;
	jint	KEY__5fCERT__5fSIGN;
	jint	KEY__5fENCIPHERMENT;
	jint	NON__5fREPUDIATION;
};
extern _jc_gnu_java_security_x509_ext_KeyUsage$fields_struct _jc_gnu_java_security_x509_ext_KeyUsage$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_KeyUsage$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_security_der_BitString$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$getKeyUsage$e8df32a6488835fe(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_KeyUsage$method_info$getKeyUsage$e8df32a6488835fe;
extern _jc_method _jc_gnu_java_security_x509_ext_KeyUsage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_KeyUsage$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_KeyUsage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$vmethods {
	struct _jc_gnu_java_security_der_BitString$object	*(*getKeyUsage$e8df32a6488835fe)(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_KeyUsage$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_KeyUsage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_KeyUsage$vmethods	gnu_java_security_x509_ext_KeyUsage;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_KeyUsage$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_KeyUsage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs {
	struct _jc_gnu_java_security_der_BitString$object	*keyUsage;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_KeyUsage$refs {
    _jc_gnu_java_security_x509_ext_KeyUsage$sub_refs	gnu_java_security_x509_ext_KeyUsage;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_KeyUsage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_KeyUsage$sub_nonrefs	gnu_java_security_x509_ext_KeyUsage;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_KeyUsage$object {
	_jc_gnu_java_security_x509_ext_KeyUsage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_KeyUsage$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_KeyUsage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_KeyUsage$vtype _jc_gnu_java_security_x509_ext_KeyUsage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_KeyUsage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_KeyUsage$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_KeyUsage_H_ */
